==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-config-session/lxqt-config-session_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Commande :</translation>
    </message>
    <message>
        <location filename="../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Attendre l'exécution de 'system-tray'</translation>
    </message>
    <message>
        <location filename="../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Choisir l&apos;application</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Lancement automatique global</translation>
    </message>
    <message>
        <location filename="../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>Lancement automatique de LXQt</translation>
    </message>
    <message>
        <location filename="../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Emplacement : %1</translation>
    </message>
    <message>
        <location filename="../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Ignorer : %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Lancement automatique d&apos;applications</translation>
    </message>
    <message>
        <location filename="../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Le fichier &apos;%1&apos; existe déjà !</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestionnaire de fenêtres</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Modules de LXQt</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Quitter la session</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Demander confirmation avant de quitter la session</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Verrouiller l&apos;écran avant veille/hibernation</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Paramètres de base</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../../basicsettings.cpp" line="146"/>
        <source>Select a window manager</source>
        <translation>Choisir un gestionnaire de fenêtres</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Choisir un émulateur de terminal</translation>
    </message>
    <message>
        <location filename="../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Choisir un navigateur de bureau</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Applications par défaut</translation>
    </message>
    <message>
        <location filename="../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Émulateur de terminal :</translation>
    </message>
    <message>
        <location filename="../../defaultappspage.ui" line="52"/>
        <location filename="../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Navigateur web :</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variables d&apos;environnement (avancé)</translation>
    </message>
    <message>
        <location filename="../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nom de la variable</translation>
    </message>
    <message>
        <location filename="../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>Lancé</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Paramétrage de la session LXQt</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Paramètres de base</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Applications par défaut</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation>Répertoires utilisateur</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Lancement automatique</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Environnement (avancé)</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Redémarrage de session requis</translation>
    </message>
    <message>
        <location filename="../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Certains paramétrages ne seront effectifs qu&apos;à la prochaine session.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation>Emplacement des fichiers personnels</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Paramètres de LXQt - Répertoires utilisateur</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Erreur lors de l&apos;application des paramètres pour l&apos;emplacement %1</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation>Choisir un emplacement</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation>Espace public</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Contient tous les fichiers visibles sur votre bureau</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Répertoire par défaut de vos téléchargements</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Répertoire par défaut de vos modèles</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation>Répertoire par défaut de de vos fichiers partagés publiquement</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Répertoire par défaut de vos documents</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation>Répertoire par défaut de votre musique</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Répertoire par défaut de vos images</translation>
    </message>
    <message>
        <location filename="../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Répertoire par défaut de vos vidéos</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-session/lxqt-config-session/lxqt-config-session_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Commande :</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Attendre l&apos;exécution de &apos;system-tray&apos;</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Choisir l&apos;application</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Lancement automatique global</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>Lancement automatique de LXQt</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Emplacement : %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Ignorer : %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Lancement automatique d&apos;applications</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Le fichier &apos;%1&apos; existe déjà !</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestionnaire de fenêtres</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Modules de LXQt</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Quitter la session</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Demander confirmation avant de quitter la session</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Verrouiller l&apos;écran avant veille/hibernation</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Paramètres de base</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="146"/>
        <source>Select a window manager</source>
        <translation>Choisir un gestionnaire de fenêtres</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Choisir un émulateur de terminal</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Choisir un navigateur de bureau</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Applications par défaut</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Émulateur de terminal :</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Navigateur web :</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variables d&apos;environnement (avancé)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nom de la variable</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>Lancé</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Paramétrage de la session LXQt</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Paramètres de base</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Applications par défaut</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation>Répertoires utilisateur</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Lancement automatique</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Environnement (avancé)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Redémarrage de session requis</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Certains paramétrages ne seront effectifs qu&apos;à la prochaine session.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation>Emplacement des fichiers personnels</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Paramètres de LXQt - Répertoires utilisateur</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Erreur lors de l&apos;application des paramètres pour l&apos;emplacement %1</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation>Choisir un emplacement</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation>Espace public</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Contient tous les fichiers visibles sur votre bureau</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Répertoire par défaut de vos téléchargements</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Répertoire par défaut de vos modèles</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation>Répertoire par défaut de de vos fichiers partagés publiquement</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Répertoire par défaut de vos documents</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation>Répertoire par défaut de votre musique</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Répertoire par défaut de vos images</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Répertoire par défaut de vos vidéos</translation>
    </message>
</context>
</TS>
